[![PyPI version](https://badge.fury.io/py/omegaconf.svg)](https://badge.fury.io/py/omegaconf)
[![Build Status](https://travis-ci.com/omry/omegaconf.svg?branch=master)](https://travis-ci.com/omry/omegaconf)

# OmegaConf
OmegaConf is a flexible yaml based configuration library, supporting dot access, deep updates and more.

See the [tutorial](https://github.com/omry/omegaconf/blob/master/tutorial/tutorial.py) for usage example.
